You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@syncope.apache.org by fm...@apache.org on 2013/02/25 16:37:34 UTC

svn commit: r1449752 - in /syncope/trunk/core/src/test: java/org/apache/syncope/core/persistence/dao/ java/org/apache/syncope/core/persistence/relationships/ java/org/apache/syncope/core/rest/ resources/

Author: fmartelli
Date: Mon Feb 25 15:37:34 2013
New Revision: 1449752

URL: http://svn.apache.org/r1449752
Log:
SYNCOPE-265 added more user info ....

Modified:
    syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttrTest.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttributableSearchTest.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/DerAttrTest.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/UserTest.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/relationships/AttrTest.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/AuthenticationTestITCase.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/RoleTestITCase.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/SearchTestITCase.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/TaskTestITCase.java
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/UserTestITCase.java
    syncope/trunk/core/src/test/resources/content.xml

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttrTest.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttrTest.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttrTest.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttrTest.java Mon Feb 25 15:37:34 2013
@@ -54,14 +54,14 @@ public class AttrTest extends AbstractDA
     @Test
     public void findAll() {
         List<UAttr> list = attrDAO.findAll(UAttr.class);
-        assertEquals("did not get expected number of attributes ", 9, list.size());
+        assertEquals("did not get expected number of attributes ", 24, list.size());
     }
 
     @Test
     public void findById() {
         UAttr attribute = attrDAO.find(100L, UAttr.class);
         assertNotNull("did not find expected attribute schema", attribute);
-        attribute = attrDAO.find(200L, UAttr.class);
+        attribute = attrDAO.find(104L, UAttr.class);
         assertNotNull("did not find expected attribute schema", attribute);
     }
 
@@ -190,7 +190,7 @@ public class AttrTest extends AbstractDA
 
     @Test
     public void delete() {
-        UAttr attribute = attrDAO.find(200L, UAttr.class);
+        UAttr attribute = attrDAO.find(104L, UAttr.class);
         String attrSchemaName = attribute.getSchema().getName();
 
         attrDAO.delete(attribute.getId(), UAttr.class);

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttributableSearchTest.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttributableSearchTest.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttributableSearchTest.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/AttributableSearchTest.java Mon Feb 25 15:37:34 2013
@@ -123,7 +123,7 @@ public class AttributableSearchTest {
     public void searchWithNotCondition() {
         final AttributeCond fullnameLeafCond = new AttributeCond(AttributeCond.Type.EQ);
         fullnameLeafCond.setSchema("fullname");
-        fullnameLeafCond.setExpression("fabio.martelli");
+        fullnameLeafCond.setExpression("Giuseppe Verdi");
 
         final NodeCond cond = NodeCond.getNotLeafCond(fullnameLeafCond);
         assertTrue(cond.isValid());
@@ -131,7 +131,7 @@ public class AttributableSearchTest {
         final List<SyncopeUser> users = searchDAO.search(EntitlementUtil.getRoleIds(entitlementDAO.findAll()), cond,
                 AttributableUtil.getInstance(AttributableType.USER));
         assertNotNull(users);
-        assertEquals(2, users.size());
+        assertEquals(4, users.size());
 
         Set<Long> ids = new HashSet<Long>(2);
         ids.add(users.get(0).getId());
@@ -256,7 +256,7 @@ public class AttributableSearchTest {
     public void searchByUsernameAndId() {
         final AttributableCond usernameLeafCond = new AttributableCond(AttributableCond.Type.EQ);
         usernameLeafCond.setSchema("username");
-        usernameLeafCond.setExpression("user1");
+        usernameLeafCond.setExpression("rossini");
 
         final AttributableCond idRightCond = new AttributableCond(AttributableCond.Type.LT);
         idRightCond.setSchema("id");
@@ -270,7 +270,7 @@ public class AttributableSearchTest {
 
         assertNotNull(matchingUsers);
         assertEquals(1, matchingUsers.size());
-        assertEquals("user1", matchingUsers.iterator().next().getUsername());
+        assertEquals("rossini", matchingUsers.iterator().next().getUsername());
         assertEquals(1L, matchingUsers.iterator().next().getId().longValue());
     }
 
@@ -302,11 +302,11 @@ public class AttributableSearchTest {
     public void searchByUsernameAndFullname() {
         final AttributableCond usernameLeafCond = new AttributableCond(AttributableCond.Type.EQ);
         usernameLeafCond.setSchema("username");
-        usernameLeafCond.setExpression("user1");
+        usernameLeafCond.setExpression("rossini");
 
         final AttributeCond idRightCond = new AttributeCond(AttributeCond.Type.LIKE);
         idRightCond.setSchema("fullname");
-        idRightCond.setExpression("fabio.mart%");
+        idRightCond.setExpression("Giuseppe V%");
 
         final NodeCond searchCondition = NodeCond.getOrCond(NodeCond.getLeafCond(usernameLeafCond),
                 NodeCond.getLeafCond(idRightCond));
@@ -389,7 +389,7 @@ public class AttributableSearchTest {
     public void issueSYNCOPE46() {
         final AttributableCond cond = new AttributableCond(AttributeCond.Type.LIKE);
         cond.setSchema("username");
-        cond.setExpression("%user%");
+        cond.setExpression("%ossin%");
 
         final NodeCond searchCondition = NodeCond.getLeafCond(cond);
         assertTrue(searchCondition.isValid());
@@ -397,6 +397,6 @@ public class AttributableSearchTest {
         final List<SyncopeUser> users = searchDAO.search(EntitlementUtil.getRoleIds(entitlementDAO.findAll()),
                 searchCondition, AttributableUtil.getInstance(AttributableType.USER));
         assertNotNull(users);
-        assertEquals(5, users.size());
+        assertEquals(1, users.size());
     }
 }

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/DerAttrTest.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/DerAttrTest.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/DerAttrTest.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/DerAttrTest.java Mon Feb 25 15:37:34 2013
@@ -191,7 +191,7 @@ public class DerAttrTest extends Abstrac
         String value = derAttr.getValue(owner.getAttributes());
         assertNotNull(value);
         assertFalse(value.isEmpty());
-        assertTrue(value.startsWith("active - user3 - 2010-10-20"));
+        assertTrue(value.startsWith("active - vivaldi - 2010-10-20"));
         assertTrue(value.endsWith("[]"));
     }
 

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/UserTest.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/UserTest.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/UserTest.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/dao/UserTest.java Mon Feb 25 15:37:34 2013
@@ -82,7 +82,7 @@ public class UserTest extends AbstractDA
     @Test
     public void findByDerAttributeValue()
             throws InvalidSearchConditionException {
-        final List<SyncopeUser> list = userDAO.findByDerAttrValue("cn", "Doe, John");
+        final List<SyncopeUser> list = userDAO.findByDerAttrValue("cn", "Vivaldi, Antonio");
         assertEquals("did not get expected number of users ", 1, list.size());
     }
 
@@ -101,7 +101,7 @@ public class UserTest extends AbstractDA
     @Test
     public void findByAttributeValue() {
         final UAttrValue fullnameValue = new UAttrValue();
-        fullnameValue.setStringValue("chicchiricco");
+        fullnameValue.setStringValue("Gioacchino Rossini");
 
         final List<SyncopeUser> list = userDAO.findByAttrValue("fullname", fullnameValue);
         assertEquals("did not get expected number of users ", 1, list.size());
@@ -128,9 +128,9 @@ public class UserTest extends AbstractDA
 
     @Test
     public void findByUsername() {
-        SyncopeUser user = userDAO.find("user1");
+        SyncopeUser user = userDAO.find("rossini");
         assertNotNull("did not find expected user", user);
-        user = userDAO.find("user3");
+        user = userDAO.find("vivaldi");
         assertNotNull("did not find expected user", user);
         user = userDAO.find("user6");
         assertNull("found user but did not expect it", user);

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/relationships/AttrTest.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/relationships/AttrTest.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/relationships/AttrTest.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/persistence/relationships/AttrTest.java Mon Feb 25 15:37:34 2013
@@ -74,26 +74,26 @@ public class AttrTest extends AbstractDA
 
     @Test
     public void deleteAttribute() {
-        attrDAO.delete(550L, UAttr.class);
+        attrDAO.delete(117L, UAttr.class);
 
         attrDAO.flush();
 
-        assertNull(attrDAO.find(550L, UAttr.class));
-        assertNull(attrValueDAO.find(22L, UAttrValue.class));
+        assertNull(attrDAO.find(117L, UAttr.class));
+        assertNull(attrValueDAO.find(28L, UAttrValue.class));
     }
 
     @Test
     public void deleteAttributeValue() {
-        UAttrValue value = attrValueDAO.find(20L, UAttrValue.class);
+        UAttrValue value = attrValueDAO.find(14L, UAttrValue.class);
         int attributeValueNumber = value.getAttribute().getValues().size();
 
-        attrValueDAO.delete(20L, UAttrValue.class);
+        attrValueDAO.delete(value.getId(), UAttrValue.class);
 
         attrValueDAO.flush();
 
-        assertNull(attrValueDAO.find(20L, UAttrValue.class));
+        assertNull(attrValueDAO.find(value.getId(), UAttrValue.class));
 
-        UAttr attribute = attrDAO.find(200L, UAttr.class);
+        UAttr attribute = attrDAO.find(104L, UAttr.class);
         assertEquals(attribute.getValues().size(), attributeValueNumber - 1);
     }
 
@@ -156,7 +156,7 @@ public class AttrTest extends AbstractDA
         String value = derAttr.getValue(owner.getAttributes());
         assertNotNull(value);
         assertFalse(value.isEmpty());
-        assertTrue(value.startsWith("user3 - 2010-10-20"));
+        assertTrue(value.startsWith("vivaldi - 2010-10-20"));
         assertTrue(value.endsWith("[]"));
     }
 }

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/AuthenticationTestITCase.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/AuthenticationTestITCase.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/AuthenticationTestITCase.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/AuthenticationTestITCase.java Mon Feb 25 15:37:34 2013
@@ -160,7 +160,7 @@ public class AuthenticationTestITCase ex
         UserTO readUserTO = userService2.read(1L);
         assertNotNull(readUserTO);
 
-        UserService userService3 = setupCredentials(userService, UserService.class, "user2", ADMIN_PWD);
+        UserService userService3 = setupCredentials(userService, UserService.class, "verdi", ADMIN_PWD);
 
         SyncopeClientException exception = null;
         try {
@@ -205,7 +205,7 @@ public class AuthenticationTestITCase ex
         }
         assertTrue(userIds.contains(1L));
 
-        UserService userService3 = setupCredentials(userService, UserService.class, "user2", "password");
+        UserService userService3 = setupCredentials(userService, UserService.class, "verdi", "password");
 
         matchedUsers = userService3.search(searchCondition);
 

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/RoleTestITCase.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/RoleTestITCase.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/RoleTestITCase.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/RoleTestITCase.java Mon Feb 25 15:37:34 2013
@@ -194,7 +194,7 @@ public class RoleTestITCase extends Abst
         assertTrue(userTO.getMembershipMap().containsKey(1L));
         assertFalse(userTO.getMembershipMap().containsKey(3L));
 
-        RoleService roleService2 = setupCredentials(roleService, RoleService.class, "user1", ADMIN_PWD);
+        RoleService roleService2 = setupCredentials(roleService, RoleService.class, "rossini", ADMIN_PWD);
 
         SyncopeClientException exception = null;
         try {
@@ -297,7 +297,7 @@ public class RoleTestITCase extends Abst
         roleMod.setName("Managing Director");
 
         // 3. try to update as user3, not owner of role 7 - fail
-        RoleService roleService2 = setupCredentials(roleService, RoleService.class, "user2", ADMIN_PWD);
+        RoleService roleService2 = setupCredentials(roleService, RoleService.class, "verdi", ADMIN_PWD);
 
         try {
             roleService2.update(roleMod.getId(), roleMod);
@@ -310,7 +310,7 @@ public class RoleTestITCase extends Abst
 
         // 4. update as user5, owner of role 7 because owner of role 6 with
         // inheritance - success
-        RoleService roleService3 = setupCredentials(roleService, RoleService.class, "user5", ADMIN_PWD);
+        RoleService roleService3 = setupCredentials(roleService, RoleService.class, "puccini", ADMIN_PWD);
 
         roleTO = roleService3.update(roleMod.getId(), roleMod);
         assertEquals("Managing Director", roleTO.getName());

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/SearchTestITCase.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/SearchTestITCase.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/SearchTestITCase.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/SearchTestITCase.java Mon Feb 25 15:37:34 2013
@@ -87,7 +87,7 @@ public class SearchTestITCase extends Ab
     public void searchByUsernameAndId() throws InvalidSearchConditionException {
         final AttributableCond usernameLeafCond = new AttributableCond(AttributableCond.Type.EQ);
         usernameLeafCond.setSchema("username");
-        usernameLeafCond.setExpression("user1");
+        usernameLeafCond.setExpression("rossini");
 
         final AttributableCond idRightCond = new AttributableCond(AttributableCond.Type.LT);
         idRightCond.setSchema("id");
@@ -102,7 +102,7 @@ public class SearchTestITCase extends Ab
 
         assertNotNull(matchingUsers);
         assertEquals(1, matchingUsers.size());
-        assertEquals("user1", matchingUsers.iterator().next().getUsername());
+        assertEquals("rossini", matchingUsers.iterator().next().getUsername());
         assertEquals(1L, matchingUsers.iterator().next().getId());
     }
 

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/TaskTestITCase.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/TaskTestITCase.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/TaskTestITCase.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/TaskTestITCase.java Mon Feb 25 15:37:34 2013
@@ -878,7 +878,6 @@ public class TaskTestITCase extends Abst
                     "SELECT USERNAME FROM testsync WHERE ID=?", String.class, userTO.getId());
             assertEquals("virtualvalue", value);
         } catch (EmptyResultDataAccessException e) {
-            LOG.error("AAAAAAAAAAAAAAAAAAAAAAA", e);
             assertTrue(false);
         }
     }

Modified: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/UserTestITCase.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/UserTestITCase.java?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================
--- syncope/trunk/core/src/test/resources/content.xml (original)
+++ syncope/trunk/core/src/test/resources/content.xml Mon Feb 25 15:37:34 2013
@@ -42,15 +42,15 @@ under the License.
   <Policy DTYPE="SyncPolicy" id="9" description="sync policy for java rule" type="SYNC" specification="%3Corg.apache.syncope.common.types.SyncPolicySpec%3E%0A++%3CconflictResolutionAction%3EIGNORE%3C/conflictResolutionAction%3E%0A%3C/org.apache.syncope.common.types.SyncPolicySpec%3E"/>
     
   <SyncopeUser id="1" workflowId="0" status="active" password="5baa61e4c9b93f3f0682250b6cf8331b7ee68fd8" cipherAlgorithm="SHA1"
-               username="user1" creationDate="2010-10-20 11:00:00" suspended="0"/>
+               username="rossini" creationDate="2010-10-20 11:00:00" suspended="0"/>
   <SyncopeUser id="2" workflowId="0" status="active" password="5baa61e4c9b93f3f0682250b6cf8331b7ee68fd8" cipherAlgorithm="SHA1"
-               username="user2" creationDate="2010-10-20 11:00:00" suspended="0"/>
+               username="verdi" creationDate="2010-10-20 11:00:00" suspended="0"/>
   <SyncopeUser id="3" workflowId="0" status="active" password="5baa61e4c9b93f3f0682250b6cf8331b7ee68fd8" cipherAlgorithm="SHA1"
-               username="user3" creationDate="2010-10-20 11:00:00" suspended="0"/>
+               username="vivaldi" creationDate="2010-10-20 11:00:00" suspended="0"/>
   <SyncopeUser id="4" workflowId="0" status="active" password="5baa61e4c9b93f3f0682250b6cf8331b7ee68fd8" cipherAlgorithm="SHA1"
-               username="user4" creationDate="2010-10-20 11:00:00" suspended="0"/>
+               username="bellini" creationDate="2010-10-20 11:00:00" suspended="0"/>
   <SyncopeUser id="5" workflowId="0" status="active" password="5baa61e4c9b93f3f0682250b6cf8331b7ee68fd8" cipherAlgorithm="SHA1"
-               username="user5" creationDate="2010-10-20 11:00:00" suspended="0"/>
+               username="puccini" creationDate="2010-10-20 11:00:00" suspended="0"/>
 
   <SyncopeRole id="1" name="root"/>
   <SyncopeRole id="2" name="child" parent_id="1"/>
@@ -155,27 +155,58 @@ under the License.
            mandatoryCondition="false" multivalue="0" uniqueConstraint="0" readonly="0"/>
 
   <UAttr id="100" owner_id="1" schema_name="fullname"/>
-  <UAttrUniqueValue id="10" attribute_id="100" schema_name="fullname" stringValue="chicchiricco"/>
-  <UAttr id="200" owner_id="1" schema_name="loginDate"/>
-  <UAttrValue attribute_id="200" id="20" dateValue="2009-05-26"/>
-  <UAttrValue attribute_id="200" id="21" dateValue="2010-05-26 15:40:04"/>
-
-  <UAttr id="300" owner_id="2" schema_name="fullname"/>
-  <UAttrUniqueValue id="11" attribute_id="300" schema_name="fullname" stringValue="fabio.martelli"/>
-
-  <UAttr id="400" owner_id="3" schema_name="firstname"/>
-  <UAttrValue attribute_id="400" id="30" stringValue="John"/>
-  <UAttr id="500" owner_id="3" schema_name="surname"/>
-  <UAttrValue attribute_id="500" id="31" stringValue="Doe"/>
-  <UAttr id="540" owner_id="3" schema_name="fullname"/>
-  <UAttrUniqueValue id="12" attribute_id="540" schema_name="fullname" stringValue="testUsername"/>
-
-  <UAttr id="550" owner_id="4" schema_name="loginDate"/>
-  <UAttrValue attribute_id="550" id="22" dateValue="2009-06-24"/>
-  <UAttr id="560" owner_id="4" schema_name="cool"/>
-  <UAttrValue attribute_id="560" id="23" booleanValue="1"/>
-  <UAttr id="561" owner_id="4" schema_name="gender"/>
-  <UAttrValue attribute_id="561" id="24" stringValue="M"/>
+  <UAttrUniqueValue id="10" attribute_id="100" schema_name="fullname" stringValue="Gioacchino Rossini"/>
+  <UAttr id="101" owner_id="1" schema_name="firstname"/>
+  <UAttrValue id="11" attribute_id="101" stringValue="Gioacchino"/>
+  <UAttr id="102" owner_id="1" schema_name="surname"/>
+  <UAttrValue id="12" attribute_id="102" stringValue="Rossini"/>
+  <UAttr id="103" owner_id="1" schema_name="userId"/>
+  <UAttrUniqueValue id="13" attribute_id="103" schema_name="userId" stringValue="rossini@apache.org"/>
+  <UAttr id="104" owner_id="1" schema_name="loginDate"/>
+  <UAttrValue id="14" attribute_id="104" dateValue="2009-05-26"/>
+  <UAttrValue id="15" attribute_id="104" dateValue="2010-05-26 15:40:04"/>
+
+  <UAttr id="105" owner_id="2" schema_name="fullname"/>
+  <UAttrUniqueValue id="16" attribute_id="105" schema_name="fullname" stringValue="Giuseppe Verdi"/>
+  <UAttr id="106" owner_id="2" schema_name="firstname"/>
+  <UAttrValue id="17" attribute_id="106" stringValue="Giuseppe"/>
+  <UAttr id="107" owner_id="2" schema_name="surname"/>
+  <UAttrValue id="18" attribute_id="107" stringValue="Verdi"/>
+  <UAttr id="108" owner_id="2" schema_name="userId"/>
+  <UAttrUniqueValue id="19" attribute_id="108" schema_name="userId" stringValue="verdi@apache.org"/>
+
+  <UAttr id="109" owner_id="3" schema_name="firstname"/>
+  <UAttrValue id="20" attribute_id="109" stringValue="Antonio"/>
+  <UAttr id="110" owner_id="3" schema_name="surname"/>
+  <UAttrValue id="21" attribute_id="110" stringValue="Vivaldi"/>
+  <UAttr id="111" owner_id="3" schema_name="fullname"/>
+  <UAttrUniqueValue id="22" attribute_id="111" schema_name="fullname" stringValue="Antonio Vivaldi"/>
+  <UAttr id="112" owner_id="3" schema_name="userId"/>
+  <UAttrUniqueValue id="23" attribute_id="112" schema_name="userId" stringValue="vivaldi@apache.org"/>
+
+  <UAttr id="113" owner_id="4" schema_name="firstname"/>
+  <UAttrValue id="24" attribute_id="113" stringValue="Vincenzo"/>
+  <UAttr id="114" owner_id="4" schema_name="surname"/>
+  <UAttrValue id="25" attribute_id="114" stringValue="Bellini"/>
+  <UAttr id="115" owner_id="4" schema_name="fullname"/>
+  <UAttrUniqueValue id="26" attribute_id="115" schema_name="fullname" stringValue="Vincenzo Bellini"/>
+  <UAttr id="116" owner_id="4" schema_name="userId"/>
+  <UAttrUniqueValue id="27" attribute_id="116" schema_name="userId" stringValue="bellini@apache.org"/>
+  <UAttr id="117" owner_id="4" schema_name="loginDate"/>
+  <UAttrValue id="28" attribute_id="117" dateValue="2009-06-24"/>
+  <UAttr id="118" owner_id="4" schema_name="cool"/>
+  <UAttrValue id="29" attribute_id="118" booleanValue="1"/>
+  <UAttr id="119" owner_id="4" schema_name="gender"/>
+  <UAttrValue id="30" attribute_id="119" stringValue="M"/>
+  
+  <UAttr id="120" owner_id="5" schema_name="firstname"/>
+  <UAttrValue id="31" attribute_id="120" stringValue="Giacomo"/>
+  <UAttr id="121" owner_id="5" schema_name="surname"/>
+  <UAttrValue id="32" attribute_id="121" stringValue="Puccini"/>
+  <UAttr id="122" owner_id="5" schema_name="fullname"/>
+  <UAttrUniqueValue id="33" attribute_id="122" schema_name="fullname" stringValue="Giacomo Puccini"/>
+  <UAttr id="123" owner_id="5" schema_name="userId"/>
+  <UAttrUniqueValue id="34" attribute_id="123" schema_name="userId" stringValue="puccini@apache.org"/>
     
   <RAttr id="600" owner_id="1" schema_name="icon"/>
   <RAttr id="700" owner_id="2" schema_name="icon"/>
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/UserTestITCase.java (original)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/UserTestITCase.java Mon Feb 25 15:37:34 2013
@@ -112,7 +112,7 @@ public class UserTestITCase extends Abst
 
     @Test
     public void selfRead() {
-        UserService userService2 = setupCredentials(userService, UserService.class, "user1", ADMIN_PWD);
+        UserService userService2 = setupCredentials(userService, UserService.class, "rossini", ADMIN_PWD);
 
         try {
             userService2.read(1L);
@@ -125,7 +125,7 @@ public class UserTestITCase extends Abst
         }
 
         UserTO userTO = userService2.readSelf();
-        assertEquals("user1", userTO.getUsername());
+        assertEquals("rossini", userTO.getUsername());
     }
 
     @Test
@@ -564,8 +564,9 @@ public class UserTestITCase extends Abst
         assertNotNull(form.getTaskId());
         assertNull(form.getOwner());
 
-        // 3. claim task from user1, not in role 7 (designated for approval in workflow definition): fail
-        UserWorkflowService userService2 = setupCredentials(userWorkflowService, UserWorkflowService.class, "user1", ADMIN_PWD);
+        // 3. claim task from rossini, not in role 7 (designated for approval in workflow definition): fail
+        UserWorkflowService userService2 = 
+                setupCredentials(userWorkflowService, UserWorkflowService.class, "rossini", ADMIN_PWD);
 
         try {
             userService2.claimForm(form.getTaskId());
@@ -574,8 +575,9 @@ public class UserTestITCase extends Abst
             assertNotNull(scce.getException(SyncopeClientExceptionType.Workflow));
         }
 
-        // 4. claim task from user4, in role 7
-        UserWorkflowService userService3 = setupCredentials(userWorkflowService, UserWorkflowService.class, "user4", ADMIN_PWD);
+        // 4. claim task from bellini, in role 7
+        UserWorkflowService userService3 = 
+                setupCredentials(userWorkflowService, UserWorkflowService.class, "bellini", ADMIN_PWD);
 
         form = userService3.claimForm(form.getTaskId());
         assertNotNull(form);

Modified: syncope/trunk/core/src/test/resources/content.xml
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/resources/content.xml?rev=1449752&r1=1449751&r2=1449752&view=diff
==============================================================================